Montage — BCI-Framework documentation

# Montage

class `bci_framework.framework.widgets.montage.` `Montage`(core)

  Widget that handle the montage, electrodes channels, and impedances.

  `change_plot`() → None

    Switch between Montage and Impedance.

  `connect`() → None

    Connect events.

  `delete_montage`(*args, **kwargs) → None

    Remove montage.

  `generate_list_channels`() → None

    Update the widgets to set the channel to the electrode.

  `get_mne_montage`() → mne.channels.DigMontage

    Create montage from GUI options.

  `load_montage`(event=None) → None

    Load the selected montage.

  `save_montage`() → None

    Save current montage.

  `set_saved_montages`() → None

    Load saved montages.

  `set_spliter_position`() → None

    Delay method to redraw the figure.

  `update_environ`() → None

    Update environment variables.

  `update_impedance`(z: Optional[List[float]] = None) → None

    Send the impedance values to the drawer.

  `update_topoplot`() → None

    Redraw topoplot.

  `validate_channels`() → None

    Highlight misconfigurations.

class `bci_framework.framework.widgets.montage.` `TopoplotBase`(*args: Any, **kwargs: Any)

  The figure will try to resize so fast that freezes the main window.

  `do_resize_now`() → None

    Resize plot.

  `resizeEvent`(event) → None

    Slow down the resize event.

class `bci_framework.framework.widgets.montage.` `TopoplotImpedances`(*args: Any, **kwargs: Any)

  Topoplot with electrodes impedances.

  `add_colorbar`() → None

    Draw color bar to indicate the impedance value.

  `raw_to_z`(v: Volts) → Impedance

    Convert voltage to impedance.

  `remove_overlaping`(info, channels_names) → None

    Remove channels that overlap positions.

  `reset_plot`() → None

    Ajust figure positions.

  `update_impedances`(montage: mne.channels.DigMontage, electrodes: List[str], impedances: Dict[str, float]) → None

    Redraw electrodes with background colors.

class `bci_framework.framework.widgets.montage.` `TopoplotMontage`(*args: Any, **kwargs: Any)

  Topoplot with electrodes positions.

  `reset_plot`() → None

    Ajust figure positions.

  `update_montage`(montage: mne.channels.DigMontage, electrodes: List[str]) → None

    Redraw electrodes positions.